Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1029)

Unified Diff: cc/layers/picture_layer.cc

Issue 2678903003: cc: Clean up naming of paint-related identifiers (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/layers/picture_layer.cc
diff --git a/cc/layers/picture_layer.cc b/cc/layers/picture_layer.cc
index 08c5761fea496103f9002e9df8c913a8216f2563..ca425afa286214e72222a29976196b0f6d98c75c 100644
--- a/cc/layers/picture_layer.cc
+++ b/cc/layers/picture_layer.cc
@@ -141,10 +141,10 @@ void PictureLayer::SetIsMask(bool is_mask) {
is_mask_ = is_mask;
}
-sk_sp<PaintRecord> PictureLayer::GetPicture() const {
- // We could either flatten the RecordingSource into a single
- // PaintRecord, or paint a fresh one depending on what we intend to do with
- // the record. For now we just paint a fresh one to get consistent results.
+sk_sp<SkPicture> PictureLayer::GetPicture() const {
+ // We could either flatten the RecordingSource into a single SkPicture, or
+ // paint a fresh one depending on what we intend to do with it. For now we
+ // just paint a fresh one to get consistent results.
if (!DrawsContent())
return nullptr;

Powered by Google App Engine
This is Rietveld 408576698